BitwuzlaRoundingMode
====================

- enum :cpp:enum:`BitwuzlaRoundingMode`
- :cpp:func:`bitwuzla_rm_to_string()`

----

.. doxygenenum:: BitwuzlaRoundingMode
    :project: Bitwuzla_c

----

.. doxygenfunction:: bitwuzla_rm_to_string
    :project: Bitwuzla_c
